@@ -13,6 +13,7 @@ import (
 
 	"github.com/abiosoft/colima/cli"
 	"github.com/abiosoft/colima/daemon/process"
+	"github.com/abiosoft/colima/util/osutil"
 	"github.com/abiosoft/colima/util/shautil"
 	"github.com/containers/gvisor-tap-vsock/pkg/transport"
 	"github.com/containers/gvisor-tap-vsock/pkg/types"
@@ -21,33 +22,43 @@ import (
 )
 
 const Name = "gvproxy"
+const CtxKeyHosts = "gvproxy.hosts"
 
 // New creates a new Process for gvproxy.
-func New() process.Process {
-	return &gvproxyProcess{}
+func New(hosts ...map[string]string) process.Process {
+	dnsHosts := map[string]string{
+		"host.lima.internal":   "192.168.5.2",
+		"host.docker.internal": "host.lima.internal",
+	}
+
+	for _, host := range hosts {
+		for k, v := range host {
+			dnsHosts[k] = v
+		}
+	}
+	return &gvproxyProcess{
+		hosts: dnsHosts,
+	}
 }
 
-type Socket string
-
-func (s Socket) Unix() string { return "unix://" + s.File() }
-func (s Socket) File() string { return strings.TrimPrefix(string(s), "unix://") }
-
 func Info() struct {
-	Socket     Socket
+	Socket     osutil.Socket
 	MacAddress string
 } {
 	return struct {
-		Socket     Socket
+		Socket     osutil.Socket
 		MacAddress string
 	}{
-		Socket:     Socket(filepath.Join(process.Dir(), socketFileName)),
+		Socket:     osutil.Socket(filepath.Join(process.Dir(), socketFileName)),
 		MacAddress: MacAddress(),
 	}
 }
 
 var _ process.Process = (*gvproxyProcess)(nil)
 
-type gvproxyProcess struct{}
+type gvproxyProcess struct {
+	hosts hostMap
+}
 
 func (*gvproxyProcess) Alive(context.Context) error {
 	info := Info()
@@ -61,9 +72,9 @@ func (*gvproxyProcess) Alive(context.Context) error {
 func (*gvproxyProcess) Name() string { return Name }
 
 // Start implements daemon.Process
-func (*gvproxyProcess) Start(ctx context.Context) error {
+func (g *gvproxyProcess) Start(ctx context.Context) error {
 	info := Info()
-	return run(ctx, info.Socket)
+	return run(ctx, info.Socket, extractZones(g.hosts))
 }
 
 const (
@@ -95,7 +106,7 @@ func MacAddress() string {
 	return macAddress.String()
 }
 
-func configuration() types.Configuration {
+func configuration(zones []types.Zone) types.Configuration {
 	return types.Configuration{
 		Debug:             cli.Settings.Verbose,
 		CaptureFile:       "",
@@ -106,21 +117,7 @@ func configuration() types.Configuration {
 		DHCPStaticLeases: map[string]string{
 			DeviceIP: MacAddress(),
 		},
-		DNS: []types.Zone{
-			{
-				Name: "internal.",
-				Records: []types.Record{
-					{
-						Name: "host.docker",
-						IP:   net.ParseIP("192.168.5.2"),
-					},
-					{
-						Name: "host.lima",
-						IP:   net.ParseIP("192.168.5.2"),
-					},
-				},
-			},
-		},
+		DNS:              zones,
 		DNSSearchDomains: searchDomains(),
 		NAT: map[string]string{
 			natIP: "127.0.0.1",
@@ -130,14 +127,14 @@ func configuration() types.Configuration {
 	}
 }
 
-func run(ctx context.Context, qemuSocket Socket) error {
+func run(ctx context.Context, qemuSocket osutil.Socket, zones []types.Zone) error {
 	if _, err := os.Stat(qemuSocket.File()); err == nil {
 		if err := os.Remove(qemuSocket.File()); err != nil {
 			return fmt.Errorf("error removing existing qemu socket: %w", err)
 		}
 	}
 
-	conf := configuration()
+	conf := configuration(zones)
 	vn, err := virtualnetwork.New(&conf)
 	if err != nil {
 		return err
