@@ -17,9 +17,11 @@ import (
 	"github.com/abiosoft/colima/config"
 	"github.com/abiosoft/colima/config/configmanager"
 	"github.com/abiosoft/colima/daemon"
+	"github.com/abiosoft/colima/daemon/process/gvproxy"
 	"github.com/abiosoft/colima/daemon/process/vmnet"
 	"github.com/abiosoft/colima/environment"
 	"github.com/abiosoft/colima/environment/vm/lima/limautil"
+	"github.com/abiosoft/colima/qemu"
 	"github.com/abiosoft/colima/util"
 	"github.com/abiosoft/colima/util/osutil"
 	"github.com/abiosoft/colima/util/yamlutil"
@@ -87,6 +89,8 @@ func (l *limaVM) startDaemon(ctx context.Context, conf config.Config) (context.C
 	}
 
 	ctxKeyVmnet := daemon.CtxKey(vmnet.Name)
+	ctxKeyGVProxy := daemon.CtxKey(gvproxy.Name)
+	ctxKeyGVProxyHosts := daemon.CtxKey(gvproxy.CtxKeyHosts)
 
 	// use a nested chain for convenience
 	a := l.Init(ctx)
@@ -96,6 +100,10 @@ func (l *limaVM) startDaemon(ctx context.Context, conf config.Config) (context.C
 
 	a.Stage("preparing network")
 	a.Add(func() error {
+		if conf.Network.Driver == gvproxy.Name {
+			ctx = context.WithValue(ctx, ctxKeyGVProxy, true)
+			ctx = context.WithValue(ctx, ctxKeyGVProxyHosts, conf.Network.DNSHosts)
+		}
 		if conf.Network.Address {
 			ctx = context.WithValue(ctx, ctxKeyVmnet, true)
 		}
@@ -163,6 +171,7 @@ func (l *limaVM) startDaemon(ctx context.Context, conf config.Config) (context.C
 				return
 			}
 
+			// revert gvproxy to boolean
 			for _, p := range status.Processes {
 				if !p.Running {
 					ctx = context.WithValue(ctx, daemon.CtxKey(p.Name), false)
@@ -173,11 +182,23 @@ func (l *limaVM) startDaemon(ctx context.Context, conf config.Config) (context.C
 	}
 
 	// preserve vmnet context
-	if vmnetEnabled, _ := ctx.Value(daemon.CtxKey(vmnet.Name)).(bool); vmnetEnabled {
+	if vmnetEnabled, _ := ctx.Value(ctxKeyVmnet).(bool); vmnetEnabled {
 		// env var for subprocess to detect vmnet
 		l.host = l.host.WithEnv(vmnet.SubProcessEnvVar + "=1")
 	}
 
+	// preserve gvproxy context
+	if gvProxyEnabled, _ := ctx.Value(ctxKeyGVProxy).(bool); gvProxyEnabled {
+		var envs []string
+
+		// env var for subprocess to detect gvproxy
+		envs = append(envs, gvproxy.SubProcessEnvVar+"=1")
+		// use qemu wrapper for Lima by specifying wrapper binaries via env var
+		envs = append(envs, qemu.LimaDir().BinsEnvVar()...)
+
+		l.host = l.host.WithEnv(envs...)
+	}
+
 	return ctx, nil
 }
 
